@@ -187,7 +187,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -203,26 +203,26 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.aws_cloudwatch
-import aws_cdk.aws_cognito
-import aws_cdk.aws_dynamodb
-import aws_cdk.aws_ec2
-import aws_cdk.aws_elasticsearch
-import aws_cdk.aws_iam
-import aws_cdk.aws_lambda
-import aws_cdk.aws_lambda_event_sources
-import aws_cdk.aws_sqs
-import constructs
+import aws_cdk.aws_cloudwatch as _aws_cdk_aws_cloudwatch_ceddda9d
+import aws_cdk.aws_cognito as _aws_cdk_aws_cognito_ceddda9d
+import aws_cdk.aws_dynamodb as _aws_cdk_aws_dynamodb_ceddda9d
+import aws_cdk.aws_ec2 as _aws_cdk_aws_ec2_ceddda9d
+import aws_cdk.aws_elasticsearch as _aws_cdk_aws_elasticsearch_ceddda9d
+import aws_cdk.aws_iam as _aws_cdk_aws_iam_ceddda9d
+import aws_cdk.aws_lambda as _aws_cdk_aws_lambda_ceddda9d
+import aws_cdk.aws_lambda_event_sources as _aws_cdk_aws_lambda_event_sources_ceddda9d
+import aws_cdk.aws_sqs as _aws_cdk_aws_sqs_ceddda9d
+import constructs as _constructs_77d1e7e8
 
 
 class DynamoDBStreamsToLambdaToElasticSearchAndKibana(
-    constructs.Construct,
+    _constructs_77d1e7e8.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-dynamodbstreams-lambda-elasticsearch-kibana.DynamoDBStreamsToLambdaToElasticSearchAndKibana",
 ):
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         domain_name: builtins.str,
@@ -230,15 +230,15 @@ class DynamoDBStreamsToLambdaToElasticSearchAndKibana(
         create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
         deploy_sqs_dlq_queue: typing.Optional[builtins.bool] = None,
         deploy_vpc: typing.Optional[builtins.bool] = None,
-        dynamo_event_source_props: typing.Optional[typing.Union[aws_cdk.aws_lambda_event_sources.DynamoEventSourceProps, typing.Dict[str, typing.Any]]] = None,
-        dynamo_table_props: typing.Optional[typing.Union[aws_cdk.aws_dynamodb.TableProps, typing.Dict[str, typing.Any]]] = None,
-        es_domain_props: typing.Optional[typing.Union[aws_cdk.aws_elasticsearch.CfnDomainProps, typing.Dict[str, typing.Any]]] = None,
-        existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
-        existing_table_interface: typing.Optional[aws_cdk.aws_dynamodb.ITable] = None,
-        existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-        lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
-        sqs_dlq_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
-        vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
+        dynamo_event_source_props: typing.Optional[typing.Union[_aws_cdk_aws_lambda_event_sources_ceddda9d.DynamoEventSourceProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        dynamo_table_props: typing.Optional[typing.Union[_aws_cdk_aws_dynamodb_ceddda9d.TableProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        es_domain_props: typing.Optional[typing.Union[_aws_cdk_aws_elasticsearch_ceddda9d.CfnDomainProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        existing_lambda_obj: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function] = None,
+        existing_table_interface: typing.Optional[_aws_cdk_aws_dynamodb_ceddda9d.ITable] = None,
+        existing_vpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
+        lambda_function_props: typing.Optional[typing.Union[_aws_cdk_aws_lambda_ceddda9d.FunctionProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        sqs_dlq_queue_props: typing.Optional[typing.Union[_aws_cdk_aws_sqs_ceddda9d.QueueProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        vpc_props: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.VpcProps, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: - represents the scope for all the resources.
@@ -262,27 +262,7 @@ class DynamoDBStreamsToLambdaToElasticSearchAndKibana(
         :summary: Constructs a new instance of the LambdaToDynamoDB class.
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                domain_name: builtins.str,
-                cognito_domain_name: typing.Optional[builtins.str] = None,
-                create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
-                deploy_sqs_dlq_queue: typing.Optional[builtins.bool] = None,
-                deploy_vpc: typing.Optional[builtins.bool] = None,
-                dynamo_event_source_props: typing.Optional[typing.Union[aws_cdk.aws_lambda_event_sources.DynamoEventSourceProps, typing.Dict[str, typing.Any]]] = None,
-                dynamo_table_props: typing.Optional[typing.Union[aws_cdk.aws_dynamodb.TableProps, typing.Dict[str, typing.Any]]] = None,
-                es_domain_props: typing.Optional[typing.Union[aws_cdk.aws_elasticsearch.CfnDomainProps, typing.Dict[str, typing.Any]]] = None,
-                existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
-                existing_table_interface: typing.Optional[aws_cdk.aws_dynamodb.ITable] = None,
-                existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-                lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
-                sqs_dlq_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
-                vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__be01f23e0a62be539fba73ae854aad81bb082e113968fff7a83f671ef9e8ed36)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = DynamoDBStreamsToLambdaToElasticSearchAndKibanaProps(
@@ -306,55 +286,55 @@ class DynamoDBStreamsToLambdaToElasticSearchAndKibana(
 
     @builtins.property
     @jsii.member(jsii_name="dynamoTableInterface")
-    def dynamo_table_interface(self) -> aws_cdk.aws_dynamodb.ITable:
-        return typing.cast(aws_cdk.aws_dynamodb.ITable, jsii.get(self, "dynamoTableInterface"))
+    def dynamo_table_interface(self) -> _aws_cdk_aws_dynamodb_ceddda9d.ITable:
+        return typing.cast(_aws_cdk_aws_dynamodb_ceddda9d.ITable, jsii.get(self, "dynamoTableInterface"))
 
     @builtins.property
     @jsii.member(jsii_name="elasticsearchDomain")
-    def elasticsearch_domain(self) -> aws_cdk.aws_elasticsearch.CfnDomain:
-        return typing.cast(aws_cdk.aws_elasticsearch.CfnDomain, jsii.get(self, "elasticsearchDomain"))
+    def elasticsearch_domain(self) -> _aws_cdk_aws_elasticsearch_ceddda9d.CfnDomain:
+        return typing.cast(_aws_cdk_aws_elasticsearch_ceddda9d.CfnDomain, jsii.get(self, "elasticsearchDomain"))
 
     @builtins.property
     @jsii.member(jsii_name="elasticsearchRole")
-    def elasticsearch_role(self) -> aws_cdk.aws_iam.Role:
-        return typing.cast(aws_cdk.aws_iam.Role, jsii.get(self, "elasticsearchRole"))
+    def elasticsearch_role(self) -> _aws_cdk_aws_iam_ceddda9d.Role:
+        return typing.cast(_aws_cdk_aws_iam_ceddda9d.Role, jsii.get(self, "elasticsearchRole"))
 
     @builtins.property
     @jsii.member(jsii_name="identityPool")
-    def identity_pool(self) -> aws_cdk.aws_cognito.CfnIdentityPool:
-        return typing.cast(aws_cdk.aws_cognito.CfnIdentityPool, jsii.get(self, "identityPool"))
+    def identity_pool(self) -> _aws_cdk_aws_cognito_ceddda9d.CfnIdentityPool:
+        return typing.cast(_aws_cdk_aws_cognito_ceddda9d.CfnIdentityPool, jsii.get(self, "identityPool"))
 
     @builtins.property
     @jsii.member(jsii_name="lambdaFunction")
-    def lambda_function(self) -> aws_cdk.aws_lambda.Function:
-        return typing.cast(aws_cdk.aws_lambda.Function, jsii.get(self, "lambdaFunction"))
+    def lambda_function(self) -> _aws_cdk_aws_lambda_ceddda9d.Function:
+        return typing.cast(_aws_cdk_aws_lambda_ceddda9d.Function, jsii.get(self, "lambdaFunction"))
 
     @builtins.property
     @jsii.member(jsii_name="userPool")
-    def user_pool(self) -> aws_cdk.aws_cognito.UserPool:
-        return typing.cast(aws_cdk.aws_cognito.UserPool, jsii.get(self, "userPool"))
+    def user_pool(self) -> _aws_cdk_aws_cognito_ceddda9d.UserPool:
+        return typing.cast(_aws_cdk_aws_cognito_ceddda9d.UserPool, jsii.get(self, "userPool"))
 
     @builtins.property
     @jsii.member(jsii_name="userPoolClient")
-    def user_pool_client(self) -> aws_cdk.aws_cognito.UserPoolClient:
-        return typing.cast(aws_cdk.aws_cognito.UserPoolClient, jsii.get(self, "userPoolClient"))
+    def user_pool_client(self) -> _aws_cdk_aws_cognito_ceddda9d.UserPoolClient:
+        return typing.cast(_aws_cdk_aws_cognito_ceddda9d.UserPoolClient, jsii.get(self, "userPoolClient"))
 
     @builtins.property
     @jsii.member(jsii_name="cloudwatchAlarms")
     def cloudwatch_alarms(
         self,
-    ) -> typing.Optional[typing.List[aws_cdk.aws_cloudwatch.Alarm]]:
-        return typing.cast(typing.Optional[typing.List[aws_cdk.aws_cloudwatch.Alarm]], jsii.get(self, "cloudwatchAlarms"))
+    ) -> typing.Optional[typing.List[_aws_cdk_aws_cloudwatch_ceddda9d.Alarm]]:
+        return typing.cast(typing.Optional[typing.List[_aws_cdk_aws_cloudwatch_ceddda9d.Alarm]], jsii.get(self, "cloudwatchAlarms"))
 
     @builtins.property
     @jsii.member(jsii_name="dynamoTable")
-    def dynamo_table(self) -> typing.Optional[aws_cdk.aws_dynamodb.Table]:
-        return typing.cast(typing.Optional[aws_cdk.aws_dynamodb.Table], jsii.get(self, "dynamoTable"))
+    def dynamo_table(self) -> typing.Optional[_aws_cdk_aws_dynamodb_ceddda9d.Table]:
+        return typing.cast(typing.Optional[_aws_cdk_aws_dynamodb_ceddda9d.Table], jsii.get(self, "dynamoTable"))
 
     @builtins.property
     @jsii.member(jsii_name="vpc")
-    def vpc(self) -> typing.Optional[aws_cdk.aws_ec2.IVpc]:
-        return typing.cast(typing.Optional[aws_cdk.aws_ec2.IVpc], jsii.get(self, "vpc"))
+    def vpc(self) -> typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc]:
+        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc], jsii.get(self, "vpc"))
 
 
 @jsii.data_type(
@@ -386,15 +366,15 @@ class DynamoDBStreamsToLambdaToElasticSearchAndKibanaProps:
         create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
         deploy_sqs_dlq_queue: typing.Optional[builtins.bool] = None,
         deploy_vpc: typing.Optional[builtins.bool] = None,
-        dynamo_event_source_props: typing.Optional[typing.Union[aws_cdk.aws_lambda_event_sources.DynamoEventSourceProps, typing.Dict[str, typing.Any]]] = None,
-        dynamo_table_props: typing.Optional[typing.Union[aws_cdk.aws_dynamodb.TableProps, typing.Dict[str, typing.Any]]] = None,
-        es_domain_props: typing.Optional[typing.Union[aws_cdk.aws_elasticsearch.CfnDomainProps, typing.Dict[str, typing.Any]]] = None,
-        existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
-        existing_table_interface: typing.Optional[aws_cdk.aws_dynamodb.ITable] = None,
-        existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-        lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
-        sqs_dlq_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
-        vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
+        dynamo_event_source_props: typing.Optional[typing.Union[_aws_cdk_aws_lambda_event_sources_ceddda9d.DynamoEventSourceProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        dynamo_table_props: typing.Optional[typing.Union[_aws_cdk_aws_dynamodb_ceddda9d.TableProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        es_domain_props: typing.Optional[typing.Union[_aws_cdk_aws_elasticsearch_ceddda9d.CfnDomainProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        existing_lambda_obj: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function] = None,
+        existing_table_interface: typing.Optional[_aws_cdk_aws_dynamodb_ceddda9d.ITable] = None,
+        existing_vpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
+        lambda_function_props: typing.Optional[typing.Union[_aws_cdk_aws_lambda_ceddda9d.FunctionProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        sqs_dlq_queue_props: typing.Optional[typing.Union[_aws_cdk_aws_sqs_ceddda9d.QueueProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        vpc_props: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.VpcProps, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param domain_name: Cognito & ES Domain Name. Default: - None
@@ -415,37 +395,19 @@ class DynamoDBStreamsToLambdaToElasticSearchAndKibanaProps:
         :summary: The properties for the DynamoDBStreamsToLambdaToElastciSearchAndKibana Construct
         '''
         if isinstance(dynamo_event_source_props, dict):
-            dynamo_event_source_props = aws_cdk.aws_lambda_event_sources.DynamoEventSourceProps(**dynamo_event_source_props)
+            dynamo_event_source_props = _aws_cdk_aws_lambda_event_sources_ceddda9d.DynamoEventSourceProps(**dynamo_event_source_props)
         if isinstance(dynamo_table_props, dict):
-            dynamo_table_props = aws_cdk.aws_dynamodb.TableProps(**dynamo_table_props)
+            dynamo_table_props = _aws_cdk_aws_dynamodb_ceddda9d.TableProps(**dynamo_table_props)
         if isinstance(es_domain_props, dict):
-            es_domain_props = aws_cdk.aws_elasticsearch.CfnDomainProps(**es_domain_props)
+            es_domain_props = _aws_cdk_aws_elasticsearch_ceddda9d.CfnDomainProps(**es_domain_props)
         if isinstance(lambda_function_props, dict):
-            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
+            lambda_function_props = _aws_cdk_aws_lambda_ceddda9d.FunctionProps(**lambda_function_props)
         if isinstance(sqs_dlq_queue_props, dict):
-            sqs_dlq_queue_props = aws_cdk.aws_sqs.QueueProps(**sqs_dlq_queue_props)
+            sqs_dlq_queue_props = _aws_cdk_aws_sqs_ceddda9d.QueueProps(**sqs_dlq_queue_props)
         if isinstance(vpc_props, dict):
-            vpc_props = aws_cdk.aws_ec2.VpcProps(**vpc_props)
+            vpc_props = _aws_cdk_aws_ec2_ceddda9d.VpcProps(**vpc_props)
         if __debug__:
-            def stub(
-                *,
-                domain_name: builtins.str,
-                cognito_domain_name: typing.Optional[builtins.str] = None,
-                create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
-                deploy_sqs_dlq_queue: typing.Optional[builtins.bool] = None,
-                deploy_vpc: typing.Optional[builtins.bool] = None,
-                dynamo_event_source_props: typing.Optional[typing.Union[aws_cdk.aws_lambda_event_sources.DynamoEventSourceProps, typing.Dict[str, typing.Any]]] = None,
-                dynamo_table_props: typing.Optional[typing.Union[aws_cdk.aws_dynamodb.TableProps, typing.Dict[str, typing.Any]]] = None,
-                es_domain_props: typing.Optional[typing.Union[aws_cdk.aws_elasticsearch.CfnDomainProps, typing.Dict[str, typing.Any]]] = None,
-                existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
-                existing_table_interface: typing.Optional[aws_cdk.aws_dynamodb.ITable] = None,
-                existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-                lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
-                sqs_dlq_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
-                vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__15256a48b87205ff4838aeb7e7f6095fa6a7f9962182192eecc43a54d205b82a)
             check_type(argname="argument domain_name", value=domain_name, expected_type=type_hints["domain_name"])
             check_type(argname="argument cognito_domain_name", value=cognito_domain_name, expected_type=type_hints["cognito_domain_name"])
             check_type(argname="argument create_cloud_watch_alarms", value=create_cloud_watch_alarms, expected_type=type_hints["create_cloud_watch_alarms"])
@@ -460,7 +422,7 @@ class DynamoDBStreamsToLambdaToElasticSearchAndKibanaProps:
             check_type(argname="argument lambda_function_props", value=lambda_function_props, expected_type=type_hints["lambda_function_props"])
             check_type(argname="argument sqs_dlq_queue_props", value=sqs_dlq_queue_props, expected_type=type_hints["sqs_dlq_queue_props"])
             check_type(argname="argument vpc_props", value=vpc_props, expected_type=type_hints["vpc_props"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "domain_name": domain_name,
         }
         if cognito_domain_name is not None:
@@ -539,89 +501,97 @@ class DynamoDBStreamsToLambdaToElasticSearchAndKibanaProps:
     @builtins.property
     def dynamo_event_source_props(
         self,
-    ) -> typing.Optional[aws_cdk.aws_lambda_event_sources.DynamoEventSourceProps]:
+    ) -> typing.Optional[_aws_cdk_aws_lambda_event_sources_ceddda9d.DynamoEventSourceProps]:
         '''Optional user provided props to override the default props.
 
         :default: - Default props are used
         '''
         result = self._values.get("dynamo_event_source_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_lambda_event_sources.DynamoEventSourceProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_lambda_event_sources_ceddda9d.DynamoEventSourceProps], result)
 
     @builtins.property
-    def dynamo_table_props(self) -> typing.Optional[aws_cdk.aws_dynamodb.TableProps]:
+    def dynamo_table_props(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_dynamodb_ceddda9d.TableProps]:
         '''Optional user provided props to override the default props.
 
         :default: - Default props are used
         '''
         result = self._values.get("dynamo_table_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_dynamodb.TableProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_dynamodb_ceddda9d.TableProps], result)
 
     @builtins.property
     def es_domain_props(
         self,
-    ) -> typing.Optional[aws_cdk.aws_elasticsearch.CfnDomainProps]:
+    ) -> typing.Optional[_aws_cdk_aws_elasticsearch_ceddda9d.CfnDomainProps]:
         '''Optional user provided props to override the default props for the API Gateway.
 
         :default: - Default props are used
         '''
         result = self._values.get("es_domain_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_elasticsearch.CfnDomainProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_elasticsearch_ceddda9d.CfnDomainProps], result)
 
     @builtins.property
-    def existing_lambda_obj(self) -> typing.Optional[aws_cdk.aws_lambda.Function]:
+    def existing_lambda_obj(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function]:
         '''Existing instance of Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error.
 
         :default: - None
         '''
         result = self._values.get("existing_lambda_obj")
-        return typing.cast(typing.Optional[aws_cdk.aws_lambda.Function], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function], result)
 
     @builtins.property
-    def existing_table_interface(self) -> typing.Optional[aws_cdk.aws_dynamodb.ITable]:
+    def existing_table_interface(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_dynamodb_ceddda9d.ITable]:
         '''Existing instance of DynamoDB table object, providing both this and ``dynamoTableProps`` will cause an error.
 
         :default: - None
         '''
         result = self._values.get("existing_table_interface")
-        return typing.cast(typing.Optional[aws_cdk.aws_dynamodb.ITable], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_dynamodb_ceddda9d.ITable], result)
 
     @builtins.property
-    def existing_vpc(self) -> typing.Optional[aws_cdk.aws_ec2.IVpc]:
+    def existing_vpc(self) -> typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc]:
         '''An existing VPC for the construct to use (construct will NOT create a new VPC in this case).
 
         :default: - None
         '''
         result = self._values.get("existing_vpc")
-        return typing.cast(typing.Optional[aws_cdk.aws_ec2.IVpc], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc], result)
 
     @builtins.property
     def lambda_function_props(
         self,
-    ) -> typing.Optional[aws_cdk.aws_lambda.FunctionProps]:
+    ) -> typing.Optional[_aws_cdk_aws_lambda_ceddda9d.FunctionProps]:
         '''User provided props to override the default props for the Lambda function.
 
         :default: - Default props are used
         '''
         result = self._values.get("lambda_function_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_lambda.FunctionProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_lambda_ceddda9d.FunctionProps], result)
 
     @builtins.property
-    def sqs_dlq_queue_props(self) -> typing.Optional[aws_cdk.aws_sqs.QueueProps]:
+    def sqs_dlq_queue_props(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_sqs_ceddda9d.QueueProps]:
         '''Optional user provided properties for the SQS dead letter queue.
 
         :default: - Default props are used
         '''
         result = self._values.get("sqs_dlq_queue_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_sqs.QueueProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_sqs_ceddda9d.QueueProps], result)
 
     @builtins.property
-    def vpc_props(self) -> typing.Optional[aws_cdk.aws_ec2.VpcProps]:
+    def vpc_props(self) -> typing.Optional[_aws_cdk_aws_ec2_ceddda9d.VpcProps]:
         '''Properties to override default properties if deployVpc is true.
 
         :default: - DefaultIsolatedVpcProps() in vpc-defaults.ts
         '''
         result = self._values.get("vpc_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_ec2.VpcProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_ceddda9d.VpcProps], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -641,3 +611,45 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__be01f23e0a62be539fba73ae854aad81bb082e113968fff7a83f671ef9e8ed36(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    domain_name: builtins.str,
+    cognito_domain_name: typing.Optional[builtins.str] = None,
+    create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
+    deploy_sqs_dlq_queue: typing.Optional[builtins.bool] = None,
+    deploy_vpc: typing.Optional[builtins.bool] = None,
+    dynamo_event_source_props: typing.Optional[typing.Union[_aws_cdk_aws_lambda_event_sources_ceddda9d.DynamoEventSourceProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    dynamo_table_props: typing.Optional[typing.Union[_aws_cdk_aws_dynamodb_ceddda9d.TableProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    es_domain_props: typing.Optional[typing.Union[_aws_cdk_aws_elasticsearch_ceddda9d.CfnDomainProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    existing_lambda_obj: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function] = None,
+    existing_table_interface: typing.Optional[_aws_cdk_aws_dynamodb_ceddda9d.ITable] = None,
+    existing_vpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
+    lambda_function_props: typing.Optional[typing.Union[_aws_cdk_aws_lambda_ceddda9d.FunctionProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    sqs_dlq_queue_props: typing.Optional[typing.Union[_aws_cdk_aws_sqs_ceddda9d.QueueProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    vpc_props: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.VpcProps, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__15256a48b87205ff4838aeb7e7f6095fa6a7f9962182192eecc43a54d205b82a(
+    *,
+    domain_name: builtins.str,
+    cognito_domain_name: typing.Optional[builtins.str] = None,
+    create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
+    deploy_sqs_dlq_queue: typing.Optional[builtins.bool] = None,
+    deploy_vpc: typing.Optional[builtins.bool] = None,
+    dynamo_event_source_props: typing.Optional[typing.Union[_aws_cdk_aws_lambda_event_sources_ceddda9d.DynamoEventSourceProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    dynamo_table_props: typing.Optional[typing.Union[_aws_cdk_aws_dynamodb_ceddda9d.TableProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    es_domain_props: typing.Optional[typing.Union[_aws_cdk_aws_elasticsearch_ceddda9d.CfnDomainProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    existing_lambda_obj: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function] = None,
+    existing_table_interface: typing.Optional[_aws_cdk_aws_dynamodb_ceddda9d.ITable] = None,
+    existing_vpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
+    lambda_function_props: typing.Optional[typing.Union[_aws_cdk_aws_lambda_ceddda9d.FunctionProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    sqs_dlq_queue_props: typing.Optional[typing.Union[_aws_cdk_aws_sqs_ceddda9d.QueueProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    vpc_props: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.VpcProps, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
